==> haskell-sourcemap-0.1.6-133-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-3szrYtj1W2u2tm73ojCnMn
key: sourcemap-0.1.6-3szrYtj1W2u2tm73ojCnMn
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 12cbbef8fddaf1314a26921a73f6a3f2
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-3szrYtj1W2u2tm73ojCnMn
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 text-1.2.3.1
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-134-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-CEdvKp1hdpv7bxhTUjhggU
key: sourcemap-0.1.6-CEdvKp1hdpv7bxhTUjhggU
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: bca479b7721c13481d284f4cb348f043
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-CEdvKp1hdpv7bxhTUjhggU
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 text-1.2.3.1
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
